@@ -6,18 +6,10 @@ ggplot(as.data.frame(Titanic),
   stat_stratum(geom = "errorbar") +
   geom_line(stat = "flow") +
   stat_flow(geom = "pointrange") +
-  geom_text(stat = "stratum", label.strata = TRUE) +
-  scale_x_discrete(limits = c("Class", "Sex", "Age"))
-
-# use of lode controls
-ggplot(as.data.frame(Titanic),
-       aes(y = Freq,
-           axis1 = Class, axis2 = Sex, axis3 = Age)) +
-  geom_flow(aes(fill = Survived), aes.bind = TRUE, reverse = FALSE) +
-  geom_stratum(reverse = FALSE) +
-  geom_text(stat = "stratum", label.strata = TRUE, reverse = FALSE) +
+  geom_text(stat = "stratum", infer.label = TRUE) +
   scale_x_discrete(limits = c("Class", "Sex", "Age"))
 
+# alluvium--flow comparison
 data(vaccinations)
 gg <- ggplot(vaccinations,
              aes(x = survey, stratum = response, alluvium = subject,
@@ -29,6 +21,30 @@ gg + geom_flow(stat = "alluvium", lode.guidance = "forward")
 # memoryless flows for vaccine survey data
 gg + geom_flow()
 
+# size filter examples
+gg <- ggplot(vaccinations,
+       aes(y = freq,
+           x = survey, stratum = response, alluvium = subject,
+           fill = response, label = response)) +
+  stat_stratum(alpha = .5) +
+  geom_text(stat = "stratum")
+# omit small flows
+gg + geom_flow(min.y = 50)
+# omit large flows
+gg + geom_flow(max.y = 100)
+
+# negate missing entries
+ggplot(vaccinations,
+       aes(y = freq,
+           x = survey, stratum = response, alluvium = subject,
+           fill = response, label = response,
+           alpha = response != "Missing")) +
+  stat_stratum(negate.strata = "Missing") +
+  geom_flow(negate.strata = "Missing") +
+  geom_text(stat = "stratum", alpha = 1, negate.strata = "Missing") +
+  scale_alpha_discrete(range = c(.2, .6)) +
+  guides(alpha = FALSE)
+
 # aesthetics that vary betwween and within strata
 data(vaccinations)
 vaccinations$subgroup <- LETTERS[1:2][rbinom(
@@ -45,15 +61,7 @@ ggplot(vaccinations,
 ggplot(vaccinations,
        aes(x = survey, stratum = response, alluvium = subject,
            y = freq, label = response)) +
-  geom_flow(aes(fill = interaction(response, subgroup)), aes.bind = TRUE) +
+  geom_flow(aes(fill = interaction(response, subgroup)), aes.bind = "alluvia") +
   scale_alpha_discrete(range = c(1/3, 2/3)) +
   geom_stratum(alpha = .5) +
   geom_text(stat = "stratum")
-
-data(majors)
-# omit missing lodes and incident flows
-ggplot(majors,
-       aes(x = semester, stratum = curriculum, alluvium = student)) +
-  geom_flow(fill = "darkgrey", na.rm = TRUE) +
-  geom_stratum(aes(fill = curriculum), color = NA, na.rm = TRUE) +
-  theme_bw()
